@@ -1,5 +1,7 @@
+import sys
 from concurrent.futures import Future
 from threading import Thread
+from typing import Iterable
 from unittest.mock import Mock
 
 from scicamera import Camera
@@ -32,3 +34,16 @@ def mature_after_frames_or_timeout(
     camera.add_request_callback(callback)
 
     return future
+
+
+def requires_controls(camera: Camera, controls: Iterable[str]):
+    """Decorator to skip tests if the camera does not support the given controls."""
+    # NOTE(meawoppl) - This should be a pytest.skip(), but because of the way
+    # tests are run in subprocesses, pytest.skip() doesn't work... TODO FIXME
+
+    available_controls = camera.controls.available_control_names()
+    missing_controls = set(controls) - available_controls
+
+    if missing_controls:
+        print("Skipping test, missing controls:", missing_controls)
+        sys.exit(0)
